#!/bin/bash
# add_render_process.sh <full-path-of-render-directory> <name-of-renderscript>
#                    [<remote-user-name> <remote-host-address>]
#
# Author: Burkhard Reike, 2011-10-21

if [ $# -ne 2 -a $# -ne 4 ]; then
    echo "Usage: $0 <full-path-of-render-directory> <name-of-renderscript>"
    echo "       [<remote-user-name> <remote-host-address>]"
    exit 1
else
    RENDERDIR=$1
    if [ $RENDERDIR != */ ]; then
        RENDERDIR="$RENDERDIR"/
    fi
    RENDERSCRIPT=$2
    if [ $# -eq 4 ]; then
        USER=$3
        HOST=$4
        ISMASTER=false
    else
        USER=''
        HOST=''
        ISMASTER=true
    fi
fi

if [ -d "$RENDERDIR" -a -n "$(ls -A $RENDERDIR 2> /dev/null)" ]; then
    # Render directory already exists and is non-empty, so don't mount it.
    if [ !$ISMASTER ]; then
        echo "$0: Render directory seems already mounted. Mounting omitted."
    fi
else
    # Render directory doesn't exist or it's empty. Try to mount it.
    if [ !$ISMASTER ]; then
        if [ ! -d "$RENDERDIR" ]; then
            mkdir $RENDERDIR
        fi

        #
        # Mounting the render directory via sshfs
        #
        sudo chown `whoami`:`whoami` $RENDERDIR # Fix the render dir ownership
        sudo apt-get install sshfs # Install the sshfs package. This may have
                                   # to be adjusted, depending on your Linux
                                   # distribution.
        sudo modprobe fuse                      # Load the fuse module
        sudo adduser `whoami` fuse              # Add us to the fuser group
        sudo chown root:fuse /dev/fuse          # Fix /dev/fuse ownership
        sshfs -o ServerAliveInterval=15 $USER@$HOST:$RENDERDIR $RENDERDIR

        # Wait till the render directory is non-empty
        echo "$0: Waiting for content in the render directory..."
        until [ -d "$RENDERDIR" -a -n "$(ls -A $RENDERDIR 2> /dev/null)" ]; do
            sleep 2
        done
        echo "$0: Render directory was mounted sucessfully."

    else
        # The master process needs a non-empty render directory,
        # but could not find it.
        echo "$0: Could not find script $RENDERDIR$RENDERSCRIPT. Exiting."
        exit 1
    fi
fi

echo "$0: Starting background render script $RENDERDIR$RENDERSCRIPT"
cd $RENDERDIR
./$RENDERSCRIPT &>/dev/null &
