@rem builder.bat
@rem
@rem Variables to be defined:
@rem povray  - The path of the Povray executable.
@rem povname - The name of the scene to render, without extension.
@rem digits  - The number of digits in the index of the image files.
@rem suffix  - The extension of the image files, eg. png.
@rem s       - Number of the initial frame.
@rem e       - Number of the final frame.
@rem
@rem Author: Burkhard Reike, 2011-10-29

@echo off
setLocal EnableDelayedExpansion

set povray="C:\Users\Burkhard\AppData\Roaming\POV-Ray\v3.6\bin\pvengine-sse2.exe"
set povname=landscape
set digits=5
set suffix=png
set s=1
set e=13741

echo Starting: %computername% %date% %time% >> render.log
set lockdir=%povname%.lck
for /L %%c in (%s%,1,%e%) do (
  set padcntr=0000000000%%c
  set filename=!povname!!padcntr:~-%digits%!
  call :Lock
  if not exist !filename!.%suffix% (
    type NUL > !filename!.%suffix%
    call :Unlock
    call :GetTime
    set starttime=!cseconds!
    start /WAIT /min "Render" %povray% -d +SF%%c +EF%%c /exit +I %povname%.ini
    call :GetTime
    set endtime=!cseconds!
    if !endtime! LSS !starttime! set /a endtime+=8640000
    set /a elapsed=!endtime!-!starttime!
    set /a elapsed/=100
    echo !filename!.%suffix% !elapsed! %computername% >> render.log
  ) else (
    call :Unlock
  )
)

echo Finished: %computername% %date% %time% >> render.log
goto:eof

:GetTime
for /f "usebackq tokens=1-4 delims=:., " %%f in (`echo.%time%`) do (
  set temp=%%f %%g %%h %%i
)
for /f "usebackq tokens=1-4" %%f in (`echo %temp: 0= %`) do (
  set /a cseconds=%%f*360000+%%g*6000+%%h*100+%%i
)
goto:eof

:Lock
md %lockdir% 2>NUL
if errorlevel 1 (
   rem ping seems the only "sleep" command availabe on all Windows versions
   ping -n 2 127.0.0.1 >NUL
   goto Lock
)
goto:eof

:Unlock
rd %lockdir%
goto:eof