#!/bin/bash
# builder.sh
#
# Variables to be defined:
# POVNAME - The name of the scene to render, without extension.
# DIGITS  - The number of digits in the index of the image files.
# SUFFIX  - The extension of the image files, eg. png.
# S       - Number of the initial frame.
# E       - Number of the final frame.
#
# Author: Burkhard Reike, 2011-10-29

echo "Starting: `hostname` `date`" >> render.log

POVNAME=landscape
DIGITS=5
SUFFIX=png
S=1
E=13741

LOCKDIR=$POVNAME.lck
lock() {
   while ! mkdir $LOCKDIR 2> /dev/null
   do
     sleep 1
   done
}
unlock() {
   rm -fr $LOCKDIR
}

while [ $S -le $E ]; do
    INDEX=`printf "%0"$DIGITS"d" ${S}`
    FILENAME=$POVNAME$INDEX.$SUFFIX
    lock
    if [ ! -f $FILENAME ]; then
        touch $FILENAME
        unlock
        BEFORE="$(date +%s)"
        povray +SF$S +EF$S -d +I $POVNAME.ini &> /dev/null
        AFTER="$(date +%s)"
        ELAPSED="$(expr $AFTER - $BEFORE)"
        echo "$FILENAME $ELAPSED `hostname`" >> render.log
    else
        unlock
    fi
    S=$(($S+1))
done
echo "Finished: `hostname` `date`" >> render.log